%global with_python3 1
%global with_python2 0

%if 0%{?fedora} || 0%{?rhel} >= 8
%{!?python3_pkgversion: %global python3_pkgversion 3}
%{!?python3_other_pkgversion: %global python3_other_pkgversion 36}
%else
%global python3_pkgversion 36
%global python3_other_pkgversion 3
%endif

%global modname arrow

Name:               python-%{modname}
Version:            0.14.7
Release:            1%{?dist}
Summary:            Better dates and times for Python

Group:              Development/Libraries
License:            ASL 2.0
URL:                https://pypi.io/project/arrow
Source0:            https://pypi.io/packages/source/a/%{modname}/%{modname}-%{version}.tar.gz
# This lets us drop a hard to port dep for py3 on epel7.
Patch0:             python-arrow-remove-simplejson-test.patch

BuildArch:          noarch

%description
Arrow is a Python library that offers a sensible, human-friendly approach to
creating, manipulating, formatting and converting dates, times, and timestamps.

It implements and updates the datetime type, plugging gaps in functionality,
and provides an intelligent module API that supports many common creation
scenarios.

Simply put, it helps you work with dates and times with fewer imports and a lot
less code.

%if 0%{?with_python2}
%package -n         python2-%{modname}
Summary:            Better dates and times for Python
Group:              Development/Libraries
%{?python_provide:%python_provide python2-%{modname}}

BuildRequires:      python2-devel
BuildRequires:      python2-chai

%if 0%{?fedora} || 0%{?rhel} >= 8
BuildRequires:      python2-setuptools
BuildRequires:      python2-dateutil
BuildRequires:      python2-six
BuildRequires:      python2-nose
BuildRequires:      python2-mock
BuildRequires:      python2-pytz
Requires:           python2-dateutil
Requires:           python2-six
%else
# EPEL7 versions of the same things.
BuildRequires:      python-setuptools
BuildRequires:      python-dateutil
BuildRequires:      python-six
BuildRequires:      python-nose
BuildRequires:      python-mock
BuildRequires:      pytz
Requires:           python-dateutil
Requires:           python-six
%endif


%description -n python2-%{modname}
Arrow is a Python library that offers a sensible, human-friendly approach to
creating, manipulating, formatting and converting dates, times, and timestamps.

It implements and updates the datetime type, plugging gaps in functionality,
and provides an intelligent module API that supports many common creation
scenarios.

Simply put, it helps you work with dates and times with fewer imports and a lot
less code.

%endif

%if 0%{?with_python3}
%package -n         python%{python3_pkgversion}-%{modname}
Summary:            Better dates and times for Python
Group:              Development/Libraries

BuildRequires:      python%{python3_pkgversion}-devel
BuildRequires:      python%{python3_pkgversion}-setuptools
BuildRequires:      python%{python3_pkgversion}-chai
BuildRequires:      python%{python3_pkgversion}-dateutil
BuildRequires:      python%{python3_pkgversion}-six
BuildRequires:      python%{python3_pkgversion}-nose
BuildRequires:      python%{python3_pkgversion}-mock
BuildRequires:      python%{python3_pkgversion}-pytz

Requires:           python%{python3_pkgversion}-dateutil
Requires:           python%{python3_pkgversion}-six
Provides:           python%{python3_other_pkgversion}-%{modname} = %{version}

%description -n python%{python3_pkgversion}-%{modname}
Arrow is a Python library that offers a sensible, human-friendly approach to
creating, manipulating, formatting and converting dates, times, and timestamps.

It implements and updates the datetime type, plugging gaps in functionality,
and provides an intelligent module API that supports many common creation
scenarios.

Simply put, it helps you work with dates and times with fewer imports and a lot
less code.
%endif

%prep
%setup -q -n %{modname}-%{version}
%patch0 -p1

# Remove bundled egg-info in case it exists
rm -rf %{modname}.egg-info

%build
%if 0%{?with_python2}
%{py2_build}
%endif
%if 0%{?with_python3}
%{py3_build}
%endif

%install
%if 0%{?with_python2}
%{py2_install}
%endif
%if 0%{?with_python3}
%{py3_install}
%endif

%check
%if 0%{?with_python2}
nosetests --all-modules arrow tests
%endif

%if 0%{?with_python3}
nosetests-%{python3_version} --all-modules arrow tests
%endif

%if 0%{?with_python2}
%files -n python2-%{modname}
%doc README.rst CHANGELOG.md
%license LICENSE
%{python_sitelib}/%{modname}/
%{python_sitelib}/%{modname}-%{version}*
%endif

%if 0%{?with_python3}
%files -n python%{python3_pkgversion}-%{modname}
%doc README.rst CHANGELOG.md
%license LICENSE
%{python3_sitelib}/%{modname}/
%{python3_sitelib}/%{modname}-%{version}-*
%endif

%changelog
* Thu Mar 05 2020 Qing Lin <qing.lin@oracle.com> - 0.14.7-1
- upgrade to new version 0.14.7.

* Thu Nov 02 2017 Qing Lin <qing.lin@oracle.com> - 0.10.0-1
- upgrade to new version 0.10.0

* Wed Jul 27 2016 Ralph Bean <rbean@redhat.com> - 0.8.0-3
- Get things ready to work with py34 on epel7, someday.
- Explicit python2 subpackage.

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.0-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Wed Jun 15 2016 Ralph Bean <rbean@redhat.com> - 0.8.0-1
- new version

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Sat Oct 24 2015 Ralph Bean <rbean@redhat.com> - 0.7.0-1
- new version

* Wed Sep 16 2015 Ralph Bean <rbean@redhat.com> - 0.6.0-1
- new version
- Include license file, now shipped by upstream
- Run tests the way upstream does in their Makefile.

* Tue Sep 15 2015 Ralph Bean <rbean@redhat.com> - 0.5.0-3
- Get ready for Python34 on EPEL7.

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jan 22 2015 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.5.0-1
- Update to 0.5.0

* Wed Jan 21 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 0.4.4-1
- Update to version 0.4.4
- Enable tests (#1183352)

* Wed Jul 09 2014 Ralph Bean <rbean@redhat.com> - 0.4.2-5
- Modernize python3 macro definition.

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 14 2014 Bohuslav Kabrda <bkabrda@redhat.com> - 0.4.2-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/Python_3.4

* Tue Dec 17 2013 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.4.2-1
- Add python-six and python-dateutil as Requires

* Wed Nov 27 2013 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.4.2-1
- Update to 0.4.2
- Prepare for when the tests will be included in the releases
- Add BR to python-chai, python-dateutil and python-six

* Mon Oct 28 2013  Pierre-Yves Chibon <pingou@pingoured.fr> - 0.4.1-1
- initial package for Fedora
